%define major     2
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%bcond_with pcre

Summary:	Simple Web Indexing System for Humans - Enhanced
Name: 		swish-e
Version: 	2.4.7
Release: 	%mkrel 36
License: 	GPLv2
Group: 		Networking/Other
# These URLs are no longer valid
URL: 		http://swish-e.org/
Source: 	http://swish-e.org/distribution/%{name}-%{version}.tar.gz
Patch0:		%{name}-2.4.7-fix-str-fmt.patch
Patch1:		ac_config_header.patch
Patch2:		swish-e-typefixes.patch
# (tv) fix build with zlib-1.2.10 that has its own uncompress2():
Patch3:		fix-build-with-zlib.patch
BuildRequires:	perl-devel
BuildRequires:	pkgconfig(libxml-2.0)
%if %{with pcre}
BuildRequires:	pkgconfig(libpcre)
BuildRequires:	pkgconfig(libpcreposix)
%endif
BuildRequires:	pkgconfig(zlib)
BuildRequires:	chrpath
# (oe) require perl-SWISH-API just to play safe
Requires:	perl-SWISH-API >= %{version}


%description
Swish-e key features are :
    * Emacs/Gnus mail index in coordination with nnir.el
    * Fast - many factors that affect speed, but a search on this server
	that returns a thousand documents takes only a few seconds.
    * Flexible - a number of configuration options provide you a high degree
	of control over what is indexed and how.
    * Powerful - the AND, OR and NOT operators are supported, words can be
	truncated (using *), and searches can be limited to particular fields
	(META tag fields, TITLEs, etc.) chrpath
    * Free - nothing, zip, zero.
    * It's made for Web sites - In indexing HTML files, SWISH-E can ignore
	data in most tags while giving higher relevance to information in
	header and title tags. Titles are extracted from HTML files and appear
	in the search results. SWISH can automatically search your whole Web
	site for you in one pass, if it's under one directory. You can also
	limit your search to words in HTML titles, comments, emphasized tags,
	and META tags. In addition, 8-bit HTML characters can be indexed,
	converted, and searched.
    * It creates portable indexes - Index files consist of only one file,
	so they can be transported around and easily maintained.
    * You can fix the source - We encourage people to send in patches and
	suggestions on how to make SWISH-E better. You may want to join
	the SWISH-E Discussion.

%package -n	%{libname}
Summary:	Swish-e libraries
Group:		System/Libraries

%description -n	%{libname}
Swish-e libraries.

%package -n	%{develname}
Summary:	Swish-e devel files
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel
Provides:	lib%{name}-devel
Obsoletes:	%{mklibname %{name} 2 -d}

%description -n	%{develname}
Devel files for swish-e.

%package -n	perl-SWISH-API
Summary:	SWISH::API - Perl interface to the Swish-e C Library
Group:		Development/Perl

%description -n	perl-SWISH-API
PERL SWISH-E language bindings and scripts.

SWISH::API provides a Perl interface to the Swish-e search engine.
SWISH::API allows embedding the swish-e search code into your
application avoiding the need to fork to run the swish-e binary
and to keep an index file open when running multiple queries. This
results in increased search performance.

%prep

%setup -q
%patch -P 0 -p0
%patch -P 1 -p1 -b .ac_config_header
%patch -P 2 -p1 -b .swish-e-typefixes
%patch -P 3 -p1 -b .zlib

# perl path hack
find -type f | xargs perl -pi -e "s|/usr/local/bin/perl|%{_bindir}/perl|g"

# lib64 hack
perl -pi -e "s|/lib\"|/%{_lib}\"|g" configure.in
perl -pi -e "s|/lib -lz|/%{_lib} -lz|g" configure.in

%build
%global optflags %optflags -std=gnu17
# fix build on aarch64
autoreconf -vfi -Iconfig

%configure \
    --disable-static \
    --with-libxml2 \
    %{?with_pcre:--with-pcre} \
    --with-zlib

%make_build

# (oe) this is to fool the utterly borked perl crap
cp swish-config src/
perl -pi -e "s|^prefix=.*|prefix=%{_builddir}/%{name}-%{version}/src|g" src/swish-config
perl -pi -e "s|^includedir=.*|includedir=%{_builddir}/%{name}-%{version}/src|g" src/swish-config
perl -pi -e "s|^libdir=.*|libdir=%{_builddir}/%{name}-%{version}/src/.libs|g" src/swish-config
chmod 755 src/swish-config

pushd perl
    %{__perl} Makefile.PL \
	OPTIMIZE="%{optflags} -fPIC" \
        SWISHIGNOREVER="" \
        SWISHBINDIR="%{_builddir}/%{name}-%{version}/src" \
	INSTALLDIRS=vendor

        %make_build \
            LIB="%{_libdir}" \
            LIBS="-L%{_libdir} -L%{buildroot}/src/.libs -lswish-e -lz" \
            LDFLAGS="-L%{_libdir} -L%{_builddir}/%{name}-%{version}/src/.libs" \
            CCFLAGS="-I%{_builddir}/%{name}-%{version}/src" \
            LDDLFLAGS="-shared -L%{_builddir}/%{name}-%{version}/src/.libs/ -lswish-e"
# let's take this test off until fixed by upstream. It doesn't work on a 32 bit sytem since perl 5.14 but does on a 64 bit
#        make test
popd

# let's take this test off until fixed by upstream. It doesn't work on a 32 bit sytem since perl 5.14 but does on a 64 bit

make test

%install
%make_install

install -m0755 swish-config %{buildroot}%{_bindir}/swish-config

mv %{buildroot}/%{_docdir}/%{name} %{buildroot}/%{_docdir}/%{name}-%{version}

%make_install -C perl

# we don't want these
find %{buildroot} -name "*.la" -delete

# nuke rpath
# let's take this off, the program doesn't build with it.
find %{buildroot}%{perl_vendorarch} -type f -name "*.so" | xargs chmod u+w
find %{buildroot}%{perl_vendorarch} -type f -name "*.so" | xargs chrpath -d
chrpath -d %{buildroot}%{_bindir}/swish-e

%files
%{_docdir}/%{name}-%{version}
%{_bindir}/swish-e
%{_datadir}/%{name}/
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_bindir}/swish-config
%{_libdir}/*.so
%{_includedir}/*.h
%{_libdir}/pkgconfig/*

%files -n perl-SWISH-API
%doc perl/Changes perl/README
%{_bindir}/swish-filter-test
%{_prefix}/lib/%{name}/
%{perl_vendorarch}/auto/SWISH/API/API.so
%{perl_vendorarch}/SWISH/API.pm
%{_mandir}/man3/SWISH::API.3pm*


%changelog
* Sat May 24 2025 daviddavid <daviddavid> 2.4.7-36.mga10
+ Revision: 2186164
- fix build with gcc 15 using -std=gnu17

* Sun Mar 16 2025 wally <wally> 2.4.7-35.mga10
+ Revision: 2165031
- rebuild for libxml2 2.13.6

* Sat Aug 24 2024 daviddavid <daviddavid> 2.4.7-34.mga10
+ Revision: 2090244
- rebuild for perl 5.40.0

* Tue Dec 05 2023 daviddavid <daviddavid> 2.4.7-33.mga10
+ Revision: 2013222
- rebuild for new perl 5.38.0

* Sun Apr 16 2023 daviddavid <daviddavid> 2.4.7-32.mga9
+ Revision: 1953314
- disable old pcre support in Mageia 9 (mga#31791)

* Tue Jun 07 2022 umeabot <umeabot> 2.4.7-31.mga9
+ Revision: 1862780
- Rebuild for Perl 5.36

* Fri Mar 18 2022 umeabot <umeabot> 2.4.7-30.mga9
+ Revision: 1798775
- Mageia 9 Mass Rebuild

* Tue Oct 05 2021 tv <tv> 2.4.7-29.mga9
+ Revision: 1749653
- fix build with zlib-1.2.10 that has its own uncompress2()
  regression from mga#28839
+ umeabot <umeabot>
- Rebuild for perl 5.34

* Wed Jun 17 2020 umeabot <umeabot> 2.4.7-27.mga8
+ Revision: 1595323
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 2.4.7-26.mga8
+ Revision: 1530108
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Aug 27 2019 tmb <tmb> 2.4.7-25.mga8
+ Revision: 1433904
- rebuild for perl 5.30

* Sun Sep 23 2018 umeabot <umeabot> 2.4.7-24.mga7
+ Revision: 1301266
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 tv <tv> 2.4.7-23.mga7
+ Revision: 1250787
- fix pathes with perl-5.28
+ daviddavid <daviddavid>
- rebuild for new perl 5.28.0

* Mon Jul 09 2018 wally <wally> 2.4.7-21.mga7
+ Revision: 1242778
- fix build on aarch64
- drop multiarch leftovers
- disable static build and drop .la files
- BR libpcreposix

* Sat Jul 22 2017 neoclust <neoclust> 2.4.7-20.mga7
+ Revision: 1126677
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 2.4.7-19.mga6
+ Revision: 1036604
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 2.4.7-18.mga6
+ Revision: 958918
- Mageia 6 Mass Rebuild

* Sat Jun 27 2015 tv <tv> 2.4.7-17.mga6
+ Revision: 846158
- rebuild with soname-ified perl

* Tue Jun 23 2015 sander85 <sander85> 2.4.7-16.mga6
+ Revision: 841636
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 2.4.7-15.mga5
+ Revision: 747515
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.4.7-14.mga5
+ Revision: 689644
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 2.4.7-13.mga5
+ Revision: 631943
- Rebuild for perl 5.20

* Wed Dec 11 2013 spuhler <spuhler> 2.4.7-12.mga4
+ Revision: 556386
- added swish-e-typefixes.patch
  * fixes bug # 11880

* Sat Oct 19 2013 umeabot <umeabot> 2.4.7-11.mga4
+ Revision: 532209
- Mageia 4 Mass Rebuild

* Sat Aug 17 2013 wally <wally> 2.4.7-10.mga4
+ Revision: 467370
- fix file rights problem with chrpath
- enable chrpath usage again

* Thu Aug 15 2013 spuhler <spuhler> 2.4.7-9.mga4
+ Revision: 466642
- removed the clean section from the spec since it's not needed anymore
- commented out the # Nuke rpath section to make it build.

* Wed May 29 2013 fwang <fwang> 2.4.7-8.mga4
+ Revision: 430322
- rebuild for new perl

* Mon Jan 14 2013 umeabot <umeabot> 2.4.7-7.mga3
+ Revision: 383850
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 spuhler <spuhler> 2.4.7-6.mga3
+ Revision: 343513
- added patch to change obsolete macro AM-HEADER to AC-HEADER

* Fri Jun 01 2012 jquelin <jquelin> 2.4.7-5.mga3
+ Revision: 252840
- perl 5.16 rebuild

* Fri Jul 22 2011 spuhler <spuhler> 2.4.7-4.mga2
+ Revision: 127823
- increased rel to 4
  commented out the make test until upstream fixes the 32 bit problem
+ sander85 <sander85>
- Rebuild for perl 5.14

* Mon Feb 07 2011 spuhler <spuhler> 2.4.7-2.mga1
+ Revision: 48432
- removed buildroot definition from .spec
  removed the if mdkversion lines
- imported package swish-e


* Thu Jul 22 2010 Jérôme Quelin <jquelin@mandriva.org> 2.4.7-2mdv2011.0
+ Revision: 556781
- perl 5.12 rebuild

* Tue Oct 06 2009 Rémy Clouard <shikamaru@mandriva.org> 2.4.7-1mdv2010.0
+ Revision: 454345
- fix #35787
- fix build errors (string format)
- fix Source link
- new upstream release (2009-04-05)

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - rebuild
    - rebuild
    - rebuild for new perl
    - kill re-definition of %%buildroot on Pixel's request

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sun Nov 25 2007 Oden Eriksson <oeriksson@mandriva.com> 2.4.5-1mdv2008.1
+ Revision: 111901
- import swish-e


* Sun Nov 25 2007 Oden Eriksson <oeriksson@mandriva.com> 2.4.5-1mdv2008.1
- fix #35779 (swish-e version bump request)

* Sun Jun 19 2005 Oden Eriksson <oeriksson@mandriva.com> 2.4.3-3mdk
- added the missing perl bindigs partly as of the provided 
  spec file
- fix deps

* Tue May 10 2005 Lenny Cartier <lenny@mandrakesoft.com> 2.4.3-2mdk
- fixes for x86-64

* Thu May 10 2005 Lenny Cartier <lenny@mandrakesoft.com> 2.4.3-1mdk
- 2.4.3

* Fri Jul 02 2004 Lenny Cartier <lenny@mandrakesoft.com> 2.2.3-2mdk
- rebuild

* Thu Jun 12 2003 Marcel Pol <mpol@gmx.net> 2.2.3-1mdk
- 2.2.3

* Thu Nov 22 2001 Yves Duret <yduret@mandrakesoft.com> 2.0.5-2mdk
- update url
- rebuild

* Mon Sep 03 2001 Yves Duret <yduret@mandrakesoft.com> 2.0.5-1mdk
- first mandrake version 
